@@ -135,6 +135,9 @@ device_initcall(a9m2410_devices_init);
 
 static int a9m2410_console_init(void)
 {
+	barebox_set_model("Digi A9M2410");
+	barebox_set_hostname("a9m2410");
+
 	s3c24xx_add_uart1();
 	return 0;
 }
