@@ -33,13 +33,13 @@
 #include <nand.h>
 #include <net.h>
 #include <partition.h>
+#include <gpio.h>
 
 #include <asm/armlinux.h>
 #include <io.h>
 #include <generated/mach-types.h>
 #include <asm/mmu.h>
 
-#include <mach/gpio.h>
 #include <mach/imx-nand.h>
 #include <mach/imx35-regs.h>
 #include <mach/iomux-mx35.h>
@@ -227,6 +227,9 @@ device_initcall(eukrea_cpuimx35_devices_init);
 
 static int eukrea_cpuimx35_console_init(void)
 {
+	barebox_set_model("Eukrea CPUIMX35");
+	barebox_set_hostname("eukrea-cpuimx35");
+
 	imx35_add_uart0();
 	return 0;
 }
