@@ -19,6 +19,7 @@
 #include <gpio.h>
 #include <environment.h>
 #include <mci.h>
+#include <linux/err.h>
 #include <asm/armlinux.h>
 #include <generated/mach-types.h>
 #include <mach/imx-regs.h>
@@ -26,6 +27,7 @@
 #include <mach/mci.h>
 #include <usb/fsl_usb2.h>
 #include <mach/usb.h>
+#include <mach/iomux.h>
 
 static struct mxs_mci_platform_data mci_pdata = {
 	.caps = MMC_CAP_4_BIT_DATA | MMC_CAP_SD_HIGHSPEED | MMC_CAP_MMC_HIGHSPEED,
@@ -94,8 +96,11 @@ static int register_persistant_environment(void)
 	}
 
 	/* use the full partition as our persistent environment storage */
-	return devfs_add_partition("disk0.1", 0, cdev->size,
+	cdev = devfs_add_partition("disk0.1", 0, cdev->size,
 						DEVFS_PARTITION_FIXED, "env0");
+	if (IS_ERR(cdev))
+		return PTR_ERR(cdev);
+	return 0;
 }
 
 static int mx23_evk_devices_init(void)
@@ -130,6 +135,9 @@ device_initcall(mx23_evk_devices_init);
 
 static int mx23_evk_console_init(void)
 {
+	barebox_set_model("Freescale i.MX23 EVK");
+	barebox_set_hostname("mx23evk");
+
 	add_generic_device("stm_serial", 0, NULL, IMX_DBGUART_BASE, 8192,
 			   IORESOURCE_MEM, NULL);
 	
