@@ -21,12 +21,12 @@
 #include <init.h>
 #include <driver.h>
 #include <sizes.h>
+#include <gpio.h>
 #include <environment.h>
 #include <mach/imx25-regs.h>
 #include <asm/armlinux.h>
 #include <asm/sections.h>
 #include <asm/barebox-arm.h>
-#include <mach/gpio.h>
 #include <io.h>
 #include <partition.h>
 #include <generated/mach-types.h>
@@ -149,6 +149,9 @@ static int tx25_console_init(void)
 {
 	mxc_iomux_v3_setup_multiple_pads(tx25_pads, ARRAY_SIZE(tx25_pads));
 
+	barebox_set_model("Ka-Ro TX25");
+	barebox_set_hostname("tx25");
+
 	imx25_add_uart0();
 	return 0;
 }
