@@ -18,6 +18,7 @@
 #include <console.h>
 #include <init.h>
 #include <driver.h>
+#include <gpio.h>
 #include <io.h>
 #include <ns16550.h>
 #include <asm/armlinux.h>
@@ -35,13 +36,15 @@
 #include <partition.h>
 #include <nand.h>
 #include <asm/mmu.h>
-#include <mach/gpio.h>
 #include <mach/gpmc.h>
 #include <mach/gpmc_nand.h>
 #include <i2c/i2c.h>
 
 static int pcm049_console_init(void)
 {
+	barebox_set_model("Phytec phyCORE-OMAP4460");
+	barebox_set_hostname("phycore-omap4460");
+
 	omap44xx_add_uart3();
 
 	return 0;
