@@ -1745,16 +1745,17 @@ void *calloc(size_t n, size_t elem_size)
 	mchunkptr p;
 	INTERNAL_SIZE_T csz;
 	INTERNAL_SIZE_T sz = n * elem_size;
+	void *mem;
 
 	/* check if expand_top called, in which case don't need to clear */
 	mchunkptr oldtop = top;
 	INTERNAL_SIZE_T oldtopsize = chunksize(top);
 
-	void *mem = malloc(sz);
-
 	if ((long)n < 0)
 		return NULL;
 
+	mem = malloc(sz);
+
 	if (!mem)
 		return NULL;
 	else {
