@@ -82,7 +82,7 @@ struct phy_device *mdiobus_scan(struct mii_bus *bus, int addr)
 		return bus->phy_map[addr];
 
 	phydev = get_phy_device(bus, addr);
-	if (IS_ERR(phydev) || phydev == NULL)
+	if (IS_ERR(phydev))
 		return phydev;
 
 	bus->phy_map[addr] = phydev;
