@@ -15,6 +15,8 @@
 #include <common.h>
 #include <init.h>
 #include <io.h>
+#include <of.h>
+#include <errno.h>
 #include <driver.h>
 #include <usb/usb.h>
 #include <usb/ehci.h>
