@@ -41,9 +41,16 @@
 
 #define BAREBOX_MAGICVARS	KEEP(*(SORT_BY_NAME(.barebox_magicvar*)))
 
+#define BAREBOX_CLK_TABLE()			\
+	. = ALIGN(8);				\
+	__clk_of_table_start = .;		\
+	KEEP(*(.__clk_of_table_*));		\
+	__clk_of_table_end = .;
+
 #define BAREBOX_DTB()				\
+	. = ALIGN(8);				\
 	__dtb_start = .;			\
-	KEEP(*(.dtb.rodata.*));				\
+	KEEP(*(.dtb.rodata.*));			\
 	__dtb_end = .;
 
 #if defined(CONFIG_ARCH_BAREBOX_MAX_BARE_INIT_SIZE) && \
